@@ -8,7 +8,10 @@ MainWindow::MainWindow(QWidget *parent) :
     radio=0;
     isFullScreen=false;
     metaDataTimer = new QTimer;
+    restartTimer = new QTimer;
+    restartTimer->setSingleShot(true);
     connect(metaDataTimer, SIGNAL(timeout()), SLOT(getMetaData()));
+    connect(restartTimer, SIGNAL(timeout()), SLOT(restartRadio()));
 
     alternateBoolean = true;
 
@@ -29,36 +32,7 @@ MainWindow::MainWindow(QWidget *parent) :
 
     setWidgetsEnabled(false);
 
-    QDBusConnection::systemBus().connect("com.nokia.csd.Call",
-                                         "/com/nokia/csd/call",
-                                         "com.nokia.csd.Call",
-                                         "Coming",
-                                         this, SLOT(callIncoming()));
-
-    QDBusConnection::systemBus().connect("com.nokia.csd.Call",
-                                         "/com/nokia/csd/call",
-                                         "com.nokia.csd.Call",
-                                         "Created",
-                                         this, SLOT(callIncoming()));
-
-    QDBusConnection::systemBus().connect("com.nokia.csd.Call",
-                                         "/com/nokia/csd/call/1",
-                                         "com.nokia.csd.Call.Instance",
-                                         "Terminated",
-                                         this, SLOT(callEnded()));
-
-    QDBusConnection::systemBus().connect(QString(),
-                                         "/org/freedesktop/Hal/devices/platform_cam_focus",
-                                         "org.freedesktop.Hal.Device",
-                                         "PropertyModified",
-                                         this, SLOT(focusButtonPressed()));
-
-    QDBusConnection::systemBus().connect(QString(),
-                                         "/org/freedesktop/Hal/devices/computer_logicaldev_input_1",
-                                         "org.freedesktop.Hal.Device",
-                                         "Condition",
-                                         this, SLOT(headSetButtonPressed()));
-
+    createDbusConnections();
 
 
     if (inizializeAtStartUp)
@@ -96,6 +70,9 @@ void MainWindow::setButtonsIcons()
 
 void MainWindow::startRadio()
 {
+    QSettings settings("qradio", "settings");
+    lastFreq=settings.value("lastFreq").toInt();
+
     QFile file("/sys/devices/platform/gpio-switch/headphone/state");
     file.open(QIODevice::ReadOnly | QIODevice::Text);
     QTextStream t( &file );
@@ -128,10 +105,13 @@ void MainWindow::startRadio()
     infoLabel->setText("Radio started, bluetooth must not be disabled");
     infoBox->show();
 
-
+    system("amixer -qc0 cset iface=MIXER,name='Jack Bias Switch' on");
 
     metaDataTimer->start(10000);
     setWidgetsEnabled(true);
+
+    ui->actionHeadphones->setChecked(true);
+    on_actionHeadphones_triggered();
 }
 
 void MainWindow::stopRadio()
@@ -593,7 +573,7 @@ void MainWindow::on_actionManual_triggered()
 void MainWindow::on_actionAbout_triggered()
 {
     QMessageBox::about(this, tr("About QRadio"),
-                    tr("<h2>QRadio 0.4.4</h2>"
+                    tr("<h2>QRadio 0.4.9</h2>"
                        "<p>"
                        "<p>Written by Giovanni Grammatico (ggiovanni88@yahoo.it)"));
 }
@@ -807,11 +787,78 @@ void MainWindow::headSetButtonPressed()
     {
     case 1: break;
     case 2: on_nextStationButton_clicked(); break;
-    case 3: on_actionStop_Radio_triggered(); on_actionStart_Radio_triggered(); break;
+    case 3: restartRadio(); break;
     }
 
 
 
 }
 
+void MainWindow::createDbusConnections()
+{
+    QDBusConnection::systemBus().connect("com.nokia.csd.Call",
+                                         "/com/nokia/csd/call",
+                                         "com.nokia.csd.Call",
+                                         "Coming",
+                                         this, SLOT(callIncoming()));
+
+    QDBusConnection::systemBus().connect("com.nokia.csd.Call",
+                                         "/com/nokia/csd/call",
+                                         "com.nokia.csd.Call",
+                                         "Created",
+                                         this, SLOT(callIncoming()));
+
+    QDBusConnection::systemBus().connect("com.nokia.csd.Call",
+                                         "/com/nokia/csd/call/1",
+                                         "com.nokia.csd.Call.Instance",
+                                         "Terminated",
+                                         this, SLOT(callEnded()));
+
+    QDBusConnection::systemBus().connect(QString(),
+                                         "/org/freedesktop/Hal/devices/platform_cam_focus",
+                                         "org.freedesktop.Hal.Device",
+                                         "PropertyModified",
+                                         this, SLOT(focusButtonPressed()));
+
+    QDBusConnection::systemBus().connect(QString(),
+                                         "/org/freedesktop/Hal/devices/computer_logicaldev_input_1",
+                                         "org.freedesktop.Hal.Device",
+                                         "Condition",
+                                         this, SLOT(headSetButtonPressed()));
+
+    QDBusConnection::systemBus().connect(QString(),
+                                         "/com/nokia/policy/decision",
+                                         "com.nokia.policy",
+                                         "audio_actions",
+                                         this, SLOT(notificationReceived()));
+
+}
+
+void MainWindow::notificationReceived()
+{
+    qDebug()<<"Notification received";
+
+    if (radio==0)
+    {
+        qDebug()<<"Radio is off, returning.";
+        return;
+    }
+
+    if (restartTimer->isActive())
+    {
+        qDebug()<<"Timer is active, returning.";
+        return;
+    }
+
+    restartTimer->start(8000);
+    qDebug()<<"RestartTimer started";
+}
+
+void MainWindow::restartRadio()
+{
+    qDebug()<<"Restarting Radio";
+    on_actionStop_Radio_triggered();
+    on_actionStart_Radio_triggered();
+}
+
 
