@@ -38,6 +38,7 @@ private:
     Ui::MainWindow *ui;
     QRadioTuner *radio;
     QTimer *metaDataTimer;
+    QTimer *restartTimer;
 
     EmittingButton *quickAccessButton[4];
 
@@ -81,6 +82,7 @@ private:
     void stopRadio();
     void setWidgetsEnabled(bool);
     void initMaemoBanner();
+    void createDbusConnections();
 
 private slots:
     void freqChanged(int);
@@ -120,11 +122,13 @@ private slots:
 
     void callIncoming();
     void callEnded();
+    void notificationReceived();
 
     void focusButtonPressed();
     void setFocusButtonActive();
 
     void headSetButtonPressed();
+    void restartRadio();
 
 };
 
