@@ -47,6 +47,16 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
     ui->resumeAfterCallCheckBox->setChecked(resumeAfterCall);
     bool cameraFocusButtonUsed = settings.value("cameraFocusButtonUsed", true).toBool();
     ui->cameraFocusButtonUsedCheckBox->setChecked(cameraFocusButtonUsed);
+
+    int headsetButtonBehave = settings.value("headsetButtonBehave", 1).toInt();
+    switch(headsetButtonBehave)
+    {
+    case 1: ui->doNothingRadioButton->setChecked(true); break;
+    case 2: ui->switchToNextSavedStationRdioButton->setChecked(true); break;
+    case 3: ui->restartRadioRadioButton->setChecked(true); break;
+    }
+
+    setAttribute(Qt::WA_DeleteOnClose);
 }
 
 SettingsDialog::~SettingsDialog()
@@ -109,7 +119,18 @@ void SettingsDialog::on_saveButton_clicked()
     settings.setValue("resumeAfterCall", ui->resumeAfterCallCheckBox->isChecked());
     settings.setValue("cameraFocusButtonUsed", ui->cameraFocusButtonUsedCheckBox->isChecked());
 
+    if (ui->doNothingRadioButton->isChecked()) settings.setValue("headsetButtonBehave", 1);
+    if (ui->switchToNextSavedStationRdioButton->isChecked()) settings.setValue("headsetButtonBehave", 2);
+    if (ui->restartRadioRadioButton->isChecked()) settings.setValue("headsetButtonBehave", 3);
+
     emit saveButtonClicked();
 
     close();
 }
+
+void SettingsDialog::on_helpButton_clicked()
+{
+    GuideWindow *guideWindow = new GuideWindow(this);
+    guideWindow->show();
+
+}
