@@ -1,6 +1,8 @@
 #ifndef SETTINGSDIALOG_H
 #define SETTINGSDIALOG_H
 
+#include "guidewindow.h"
+
 #include <QDialog>
 
 #include <QInputDialog>
@@ -27,6 +29,8 @@ private slots:
 
     void on_saveButton_clicked();
 
+    void on_helpButton_clicked();
+
 private:
     Ui::SettingsDialog *ui;
 
